# SKA Utils

Набор утилит, которые помогают мне и команде в которой я работаю, выполнять рабочие задачи

## exehelper
Проверяет совпадает ли версия в toml-файле на сетевом диске и в классе ```CheckExeVersion```